--  Copyright (C) 2006 Solomon Peachy (pizza@shaftnet.org)

--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 2 of the License, or
--  (at your option) any later version.

--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.

--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

----------------------------------------------------------
-- v2.31 to v2.32 patch
----------------------------------------------------------

-- Drop the bulk update table

drop table bulk_update_rule;
drop sequence bulk_update_rule_id_sequence;

-- Convert focal length from a varchar to an integer
--  and aperture to a numeric type

drop view view_lens;
drop view view_lens_type;

alter table focal_length add value_num integer;
update focal_length set value_num = value::text::integer;
alter table focal_length drop value;
alter table focal_length rename value_num to value;

alter table aperture add value_num numeric;
update aperture set value_num = value::text::numeric;
alter table aperture drop value;
alter table aperture rename value_num to value;

create view view_lens as
  select lens.identifier, manufacturer.name, model, variation,
        s_min_aperture, s_max_aperture, s_min_focal_length,
        s_max_focal_length, lens.serial_number, lens.users,
        date_of_purchase, lens.purchased_new,
        manufacturer.url, (access_type.value) as access_rights
    from lens_type, lens, manufacturer, access_type,
         (select identifier as identifier, value as s_min_focal_length
                from focal_length) as t_min_focal_length,
         (select identifier as identifier, value as s_max_focal_length
                from focal_length) as t_max_focal_length,
         (select identifier as identifier, value as s_min_aperture from
                aperture) as t_min_aperture,
         (select identifier as identifier, value as s_max_aperture from
                aperture) as t_max_aperture
   where lens_type.manufacturer = manufacturer.identifier
     and lens_type.identifier = lens.type
     and lens_type.min_focal_length = t_min_focal_length.identifier
     and lens_type.max_focal_length = t_max_focal_length.identifier
     and lens_type.min_aperture = t_min_aperture.identifier
     and lens_type.max_aperture = t_max_aperture.identifier
     and lens.access_rights = access_type.identifier
   order by manufacturer.name, s_min_focal_length, model, variation;

create view view_lens_type as select lens_type.identifier, 
manufacturer.name,
        model, variation, s_min_aperture, s_max_aperture,
        s_min_focal_length, s_max_focal_length, manufacturer.url
    from lens_type, manufacturer,
         (select identifier as identifier, value as s_min_focal_length
        from focal_length) as t_min_focal_length,
         (select identifier as identifier, value as s_max_focal_length
        from focal_length) as t_max_focal_length,
         (select identifier as identifier, value as s_min_aperture from
        aperture) as t_min_aperture,
         (select identifier as identifier, value as s_max_aperture from
        aperture) as t_max_aperture
   where lens_type.manufacturer = manufacturer.identifier
     and lens_type.min_focal_length = t_min_focal_length.identifier
     and lens_type.max_focal_length = t_max_focal_length.identifier
     and lens_type.min_aperture = t_min_aperture.identifier
     and lens_type.max_aperture = t_max_aperture.identifier
   order by manufacturer.name, s_min_focal_length, model, variation;

----- Eliminate red and blue multipliers from dcraw options

alter table dcraw_options drop red_multiplier;
alter table dcraw_options drop blue_multiplier;

